==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translation>Stredový bod otáčania</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translation>Referenčný bod</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translation>Cieľový bod</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;Otočiť</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>Možnosti otáčania</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Počet kópií</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;Vymazať originál</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>P&amp;onechať originál</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>&amp;Viac kópií</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>&amp;Uhol (a):</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>Použiť aktuálnu vrstvu a vl&amp;astnosti</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translation>Stredový bod otáčania</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translation>Referenčný bod</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translation>Cieľový bod</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;Otočiť</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>Možnosti otáčania</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Počet kópií</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;Vymazať originál</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>P&amp;onechať originál</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>&amp;Viac kópií</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>&amp;Uhol (a):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Define angle using mouse cursor</source>
        <translation>Definujte uhol pomocou kurzora myši</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>Použiť aktuálnu vrstvu a vl&amp;astnosti</translation>
    </message>
</context>
</TS>
